@@ -33,7 +33,7 @@
 //! Library defines two main traits, [`StrictEncode`] and [`StrictDecode`],
 //! which should be implemented on each type that requires to be represented
 //! for client-side-validation. It also defines possible encoding error cases
-//! with [`Error`] and provides derivation macros
+//! with [`derive@Error`] and provides derivation macros
 //! `#[derive(StrictEncode, StrictDecode)]`, which are a part of
 //! `strict_encode_derive` sub-crate and represented by a default feature
 //! `derive`. Finally, it implements strict encoding traits for main data types
@@ -77,21 +77,20 @@ mod miniscript;
 pub mod net;
 mod pointers;
 mod primitives;
+mod slice32;
 pub mod strategies;
 
-pub use strategies::Strategy;
+use std::ops::Range;
+use std::string::FromUtf8Error;
+use std::{fmt, io};
 
 /// Re-exporting extended read and write functions from bitcoin consensus
 /// module so others may use semantic convenience
 /// `strict_encode::ReadExt`
 #[cfg(feature = "bitcoin")]
 pub use ::bitcoin::consensus::encode::{ReadExt, WriteExt};
-
 use amplify::IoError;
-use std::fmt;
-use std::io;
-use std::ops::Range;
-use std::string::FromUtf8Error;
+pub use strategies::Strategy;
 
 /// Binary encoding according to the strict rules that usually apply to
 /// consensus-critical data structures. May be used for network communications;
@@ -99,15 +98,16 @@ use std::string::FromUtf8Error;
 /// be kept in mind that sometime commitment may follow "fold" scheme
 /// (Merklization or nested commitments) and in such cases this trait can't be
 /// applied. It is generally recommended for consensus-related commitments to
-/// utilize [CommitVerify], [TryCommitVerify] and [EmbedCommitVerify] traits  
-/// from [paradigms::commit_verify] module.
+/// utilize `CommitVerify`, `TryCommitVerify` and `EmbedCommitVerify` traits  
+/// from `commit_verify` module.
 pub trait StrictEncode {
-    /// Encode with the given [std::io::Writer] instance; must return result
+    /// Encode with the given [`std::io::Write`] instance; must return result
     /// with either amount of bytes encoded – or implementation-specific
     /// error type.
     fn strict_encode<E: io::Write>(&self, e: E) -> Result<usize, Error>;
 
-    /// Serializes data as a byte array using [`strict_encode()`] function
+    /// Serializes data as a byte array using [`StrictEncode::strict_encode`]
+    /// function
     fn strict_serialize(&self) -> Result<Vec<u8>, Error> {
         let mut e = vec![];
         let _ = self.strict_encode(&mut e)?;
@@ -118,25 +118,25 @@ pub trait StrictEncode {
 /// Binary decoding according to the strict rules that usually apply to
 /// consensus-critical data structures. May be used for network communications.
 /// MUST NOT be used for commitment verification: even if the commit procedure
-/// uses [StrictEncode], the actual commit verification MUST be done with
-/// [CommitVerify], [TryCommitVerify] and [EmbedCommitVerify] traits, which,
+/// uses [`StrictEncode`], the actual commit verification MUST be done with
+/// `CommitVerify`, `TryCommitVerify` and `EmbedCommitVerify` traits, which,
 /// instead of deserializing (nonce operation for commitments) repeat the
 /// commitment procedure for the revealed message and verify it against the
 /// provided commitment.
 pub trait StrictDecode: Sized {
-    /// Decode with the given [std::io::Reader] instance; must either
+    /// Decode with the given [`std::io::Read`] instance; must either
     /// construct an instance or return implementation-specific error type.
     fn strict_decode<D: io::Read>(d: D) -> Result<Self, Error>;
 
     /// Tries to deserialize byte array into the current type using
-    /// [`strict_decode()`]
+    /// [`StrictDecode::strict_decode`]
     fn strict_deserialize(data: impl AsRef<[u8]>) -> Result<Self, Error> {
         Self::strict_decode(data.as_ref())
     }
 }
 
 /// Convenience method for strict encoding of data structures implementing
-/// [StrictEncode] into a byte vector.
+/// [`StrictEncode`] into a byte vector.
 pub fn strict_serialize<T>(data: &T) -> Result<Vec<u8>, Error>
 where
     T: StrictEncode,
@@ -147,7 +147,7 @@ where
 }
 
 /// Convenience method for strict decoding of data structures implementing
-/// [StrictDecode] from any byt data source.
+/// [`StrictDecode`] from any byt data source.
 pub fn strict_deserialize<T>(data: impl AsRef<[u8]>) -> Result<T, Error>
 where
     T: StrictDecode,
@@ -188,8 +188,8 @@ pub enum Error {
     /// encoded non-0 or non-1 length Vec will result in
     /// `Error::WrongOptionalEncoding`.
     #[display(
-        "Invalid value {0} met as an optional type byte, which must be equal to \
-        either 0 (no value) or 1"
+        "Invalid value {0} met as an optional type byte, which must be equal \
+         to either 0 (no value) or 1"
     )]
     WrongOptionalEncoding(u8),
 
@@ -213,8 +213,8 @@ pub enum Error {
     /// A repeated value for `{0}` found during set collection deserialization
     RepeatedValue(String),
 
-    /// Returned by the convenience method [`strict_decode()`] if not all
-    /// provided data were consumed during decoding process
+    /// Returned by the convenience method [`StrictDecode::strict_decode`] if
+    /// not all provided data were consumed during decoding process
     #[display(
         "Data were not consumed entirely during strict decoding procedure"
     )]
@@ -226,9 +226,7 @@ pub enum Error {
 
 impl From<Error> for fmt::Error {
     #[inline]
-    fn from(_: Error) -> Self {
-        fmt::Error
-    }
+    fn from(_: Error) -> Self { fmt::Error }
 }
 
 impl From<FromUtf8Error> for Error {
@@ -236,3 +234,39 @@ impl From<FromUtf8Error> for Error {
         Error::Utf8Conversion(err.utf8_error())
     }
 }
+
+/// Possible errors during TLV extension encoding and decoding process
+#[derive(Clone, PartialEq, Eq, PartialOrd, Ord, Hash, Debug, Display, Error)]
+#[display(doc_comments)]
+pub enum TlvError {
+    /// deterministic order of TLV records is broken: type {read} follows after
+    /// type {max}
+    Order {
+        /// TLV record id read at the current position
+        read: usize,
+        /// maximum value of TLV record id read previously
+        max: usize,
+    },
+
+    /// incorrect length of TLV record value: expected {expected}, but only
+    /// {actual} bytes read
+    Len {
+        /// TLV value length encoded in the TLV record
+        expected: usize,
+        /// Actual remaining length of the TLV stream
+        actual: usize,
+    },
+
+    /// repeated TLV record with id {0}
+    Repeated(usize),
+}
+
+// TODO: With 2.0 release add Tlv case to the Error enum
+impl From<TlvError> for Error {
+    fn from(err: TlvError) -> Self {
+        match err {
+            TlvError::Repeated(size) => Error::RepeatedValue(size.to_string()),
+            err => Error::DataIntegrityError(err.to_string()),
+        }
+    }
+}
